@@ -39,7 +39,7 @@ class ControlChange(MIDIMessage):
         self.value = value
         super().__init__(channel=channel)
         if not 0 <= self.control <= 127 or not 0 <= self.value <= 127:
-            raise self._EX_VALUEERROR_OOR
+            self._raise_valueerror_oor()
 
     def __bytes__(self):
         return bytes(
